# Schwarzbierbrot

Ein einfaches Brot aus Schwarzbier

*vegetarisch*

**1 Brot**

---

- *½ l* Schwarzbier
- *500 g* Mehl
- *1 TL* Salz
- *1 Pck.* Backpulver
- *1 Prise* Zucker
- Körner nach Wahl (z.B. Kürbiskerne, Sonnenblumenkerne)

---

Einfach alle Zutaten vermengen und in einer Kastenform bei 180°C für 45 Minuten backen.

Tipp: Ich nehme gerne Roggen- oder Dinkelmehl anstatt Weizenmehl. Dann wird der Teig dunkler und etwas fester.
